yt.utilities.lib.embree\_mesh package
=====================================

Submodules
----------

.. toctree::
   :maxdepth: 4

   yt.utilities.lib.embree_mesh.mesh_construction
   yt.utilities.lib.embree_mesh.mesh_intersection
   yt.utilities.lib.embree_mesh.mesh_samplers
   yt.utilities.lib.embree_mesh.mesh_traversal

Module contents
---------------

.. automodule:: yt.utilities.lib.embree_mesh
   :members:
   :undoc-members:
   :inherited-members:
   :show-inheritance:
